@@ -6,6 +6,7 @@
 #include <QDesktopServices>
 #include "errormessage.h"
 #include "stackedwindow.h"
+#include "settingsdialog.h"
 #include "dialog.h"
 
 
@@ -40,10 +41,12 @@ MainWindow::MainWindow(QWidget *parent) :
         iconCache[i] = new QPixmap();
     }
 
+    settings = new QSettings("naddeo", "QtWeather", this);
     latlon = new QString(); //graph parameter
     zcode = new QString();  //graph parameter
     wfo = new QString();    //graph parameter
     doc = new QDomDocument("document"); //will be the xml document object
+    justStarted = true;
 
     manager = new QNetworkAccessManager(this);
     mapper = new QSignalMapper(this);
@@ -60,6 +63,19 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(this, SIGNAL(uiReady()), this, SLOT(zipEvent()), Qt::QueuedConnection);
     emit uiReady();
 
+
+
+}
+
+void MainWindow::setSettings(){
+    SettingsDialog sd(&settings->value("home1", ""),
+                      &settings->value("home2", ""),
+                      &settings->value("default", 0));
+    sd.exec();
+    sd.deleteLater();
+    settings->setValue("home1", *sd.getHome1());
+    settings->setValue("home2", *sd.getHome2());
+    settings->setValue("default", *sd.getDefaultHome());
 }
 
 /**
@@ -98,14 +114,10 @@ void MainWindow::dayClick(QModelIndex index){
 void MainWindow::resizeEvent(QResizeEvent *event){
     if(event->oldSize().width() > event->size().width()){
         ui->mainLayout->setDirection(QBoxLayout::TopToBottom);
-        ui->listWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
-//        ui->tempScrollArea->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
-        ui->tempScrollArea->setMinimumWidth(440);
+        ui->listWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     }else{
         ui->mainLayout->setDirection(QBoxLayout::LeftToRight);
         ui->listWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
-//        ui->tempScrollArea->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
-        ui->tempScrollArea->setMinimumWidth(360);
     }
 }
 
@@ -141,9 +153,20 @@ void MainWindow::setDomDocument(QString *reply){
 void MainWindow::changeZip(){
     zipCache = zipCode;
     zipCode.clear();
-    Dialog *d = new Dialog(this);
-    d->exec();
-    zipCode = d->getZip();
+
+    if(!justStarted || settings->value("default") == 0){
+        Dialog *d = new Dialog(this);
+        d->exec();
+        d->deleteLater();
+        zipCode = d->getZip();
+    }else if(settings->value("default") == 1){
+        zipCode = settings->value("home1", "").toString();
+    }else if(settings->value("default") == 2){
+        zipCode = settings->value("home2", "").toString();
+    }
+    justStarted = false;
+
+
     if(!zipCode.isEmpty()){
         zipCode.truncate(5);
         QString urlString("http://www.weather.gov/forecasts/xml/SOAP_server/ndfdXMLclient.php?whichClient=LatLonListZipCode&listZipCodeList=xxxxx&product=time-series&begin=2004-01-01T00:00:00&end=2015-01-22T00:00:00&maxt=maxt&Submit=Submit");
@@ -157,8 +180,6 @@ void MainWindow::changeZip(){
         zipCode = zipCache;
         cout << "Dialog Canceled" << endl;
     }
-    d->deleteLater();
-
 }
 
 
@@ -369,6 +390,8 @@ void MainWindow::gotXML(){
             ui->weekBanner->setText("Upcoming Days");
             ui->weekBanner->setPalette(QApplication::palette().highlight().color());
             ui->title->setPalette(QApplication::palette().highlight().color());
+            ui->forecastLabel->setPalette(QApplication::palette().highlight().color());
+            ui->forecastLabel->setText("Hourly Temperatures: ");
         }
 
         pg->hide();
