@@ -9,6 +9,7 @@
 #include <QNetworkReply>
 #include <QResizeEvent>
 #include <QUrl>
+#include <QSettings>
 #include "progressdialog.h"
 #include "stackedwindow.h"
 #include "dayperiod.h"
@@ -33,6 +34,7 @@ signals:
 
 private:
     Ui::MainWindow *ui;
+    QSettings* settings;
     QDomDocument *doc;
     QNetworkAccessManager *manager;
     QSignalMapper* mapper;
@@ -46,6 +48,7 @@ private:
     QIcon *icon;
     int iconCount;
     bool needShowList;
+    bool justStarted;
     ProgressDialog *pg;
 
     void detailWindow(int day);
@@ -65,6 +68,7 @@ private slots:
 
     void dayClick(QModelIndex index);
     void changeZip();
+    void setSettings();
     void visitNAOO();
     void zipEvent(){
         changeZip();
