@@ -38,9 +38,10 @@ echo '2. Folder should be in /scratchbox/users/anthony/home/anthony/'
 echo '3. cd to that top level directory'
 echo '4. export DEBFULLNAME="Anthony Naddeo"'
 echo '5. dh_make --createorig --single -e anthony.naddeo@gmail.com -c gpl'
-echo '6. use dch to edit the changelog'
-echo '6. edit the control and rules files in the debian directory'
-echo '7. dpkg-buildpackage -i -rfakeroot -kanthony.naddeo@gmail.com -D'
+echo '6. use dch to edit the changelog in the full bash terminal, not scratchbox'
+echo '6. edit the control, changelog and rules files in the debian directory'
+echo '7. remove the orig.tar.gz from the directory or the debian folder wont get built into the archive!'
+echo '8. dpkg-buildpackage -i -rfakeroot -kanthony.naddeo@gmail.com -D'
 
 #echo $1-$2
 
